==> 2.5.0.zip: cloudlog/application/language/italian/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('Non è permesso l\'accesso diretto allo script');

$lang['error_no_active_station_profile'] = 'Attenzione: devi impostare un luogo di stazione attiva.';

$lang['notice_turn_the_radio_on'] = 'Non hai fatto QSO oggi; è ora di accendere la radio!';

$lang['general_word_important'] = 'Importante';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Scegli file';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";

$lang['general_word_date'] = 'Data';
$lang['general_word_time'] = 'Orario';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Data/Orario';
$lang['general_word_none'] = 'Nessuno';
$lang['general_word_name'] = 'Nome';
$lang['general_word_location'] = 'Luogo';
$lang['general_word_comment'] = 'Commento';
$lang['general_word_general'] = 'Generale';
$lang['general_word_satellite'] = 'Satellite';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Note';
$lang['general_word_country'] = 'Paese';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Totale';
$lang['general_word_year'] = 'Anno';
$lang['general_word_month'] = 'Mese';

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Lavorato';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Confermato';
$lang['general_word_needed'] = 'Necessario';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'No';
$lang['general_word_yes'] = 'Si';
$lang['general_word_method'] = 'Metodo';

$lang['general_word_sent'] = 'Inviata';
$lang['general_word_received'] = 'Ricevuta';
$lang['general_word_requested'] = 'Richiesta';
$lang['general_word_queued'] = 'In coda';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Invalido (Ignora)';
$lang['general_word_qslcard'] = 'Cartolina QSL';
$lang['general_word_qslcard_management'] = 'Gestione QSL';
$lang['general_word_qslcards'] = 'Cartoline QSL';
$lang['general_word_qslcard_direct'] = 'Diretta';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Elettronica';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'Cartoline eQSL';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Modifica QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Segna QSL Ricevuta (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Segna QSL Ricevuta (Diretta)';
$lang['general_mark_qsl_rx_electronic'] = 'Segna QSL Ricevuta (Elettronico)';
$lang['general_mark_qsl_tx_bureau'] = 'Segna QSL Inviata (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Segna QSL Inviata (Direct)';
$lang['general_mark_qsl_requested'] = 'Segna QSL come richiesto';
$lang['general_mark_qsl_requested_bureau'] = 'Segna QSL come richiesto (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Segna QSL come richiesto (Diretta)';
$lang['general_mark_qsl_not_required'] = 'Segna QSL non come richiesto';

$lang['general_delete_qso'] = 'Cancella QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Distanza Totale';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Luogo Stazione';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Stazione';

$lang['gen_hamradio_call'] = 'Nominativo';
$lang['gen_hamradio_callsign'] = 'Nominativo';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Modo';
$lang['gen_hamradio_rst_sent'] = 'Inviato';
$lang['gen_hamradio_rst_rcvd'] = 'Ricevuto';
$lang['gen_hamradio_band'] = 'Banda';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Banda (RX)';
$lang['gen_hamradio_frequency'] = 'Frequenza';
$lang['gen_hamradio_frequency_rx'] = 'Frequenza (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (I)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Scambio (I)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Scambio (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Locatore';
$lang['gen_hamradio_transmit_power'] = 'Potenza di Trasmissione (W)';
$lang['gen_hamradio_propagation_mode'] = 'Modo di Propagazione';

$lang['gen_hamradio_satellite_name'] = 'Nome Satellite';
$lang['gen_hamradio_satellite_mode'] = 'Modo Satellite';

$lang['gen_hamradio_logbook'] = 'Logbook';

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'Zona CQ';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'Stato USA';
$lang['gen_hamradio_county_reference'] = 'Contea USA';
$lang['gen_hamradio_iota_reference'] = 'Referenza IOTA';
$lang['gen_hamradio_sota_reference'] = 'Referenza SOTA';
$lang['gen_hamradio_wwff_reference'] = 'Referenza WWFF';
$lang['gen_hamradio_pota_reference'] = 'Referenza POTA';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Stato';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Quadratone';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operatore';

$lang['gen_hamradio_sig'] = 'Seg';
$lang['gen_hamradio_sig_info'] = 'Info Seg';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then ";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then ";
$lang['gen_find_zone_part2'] = 'click here';
$lang['gen_find_zone_part3'] = ' to find it!';

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Hai fatto';
$lang['dashboard_qsos_today'] = 'QSO oggi!';
$lang['dashboard_qso_breakdown'] = 'Riepilogo QSO';
$lang['dashboard_countries_breakdown'] = 'Riepilogo Paesi';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Dalla data';

$lang['gen_this_qso_was_confirmed_on'] = 'Questo QSO è stato confermato il';

$lang['error_no_logbook_found'] = 'Non è stato trovato nessun logbook. È necessario definire un logbook in Logbooks di Stazione! Vai qui:';

$lang['copy_to_clipboard'] = 'Copia';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

==> 2.6.4.zip: cloudlog/application/language/italian/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('Non è permesso l\'accesso diretto allo script');

$lang['error_no_active_station_profile'] = 'Attenzione: devi impostare un luogo di stazione attiva.';

$lang['notice_turn_the_radio_on'] = 'Non hai fatto QSO oggi; è ora di accendere la radio!';

$lang['general_word_important'] = 'Importante';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Scegli file';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";
$lang['general_word_count'] = "Count";
$lang['general_word_filtering_on'] = "Filtering on";
$lang['general_word_not_display'] = "Not display";
$lang['general_word_icon'] = "Icon";
$lang['general_word_never'] = "Never";

$lang['general_word_date'] = 'Data';
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";
$lang['general_word_time'] = 'Orario';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Data/Orario';
$lang['general_word_none'] = 'Nessuno';
$lang['general_word_name'] = 'Nome';
$lang['general_word_location'] = 'Luogo';
$lang['general_word_comment'] = 'Commento';
$lang['general_word_general'] = 'Generale';
$lang['general_word_satellite'] = 'Satellite';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Note';
$lang['general_word_country'] = 'Paese';
$lang['general_word_city'] = 'City';

$lang['general_word_total'] = 'Totale';
$lang['general_word_year'] = 'Anno';
$lang['general_word_month'] = 'Mese';
$lang['general_word_day'] = "Day";
$lang['general_word_days'] = "Days";

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Lavorato';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Confermato';
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_needed'] = 'Necessario';

$lang['general_word_all'] = 'All';
$lang['general_word_no'] = 'No';
$lang['general_word_yes'] = 'Si';
$lang['general_word_method'] = 'Metodo';

$lang['general_word_sent'] = 'Inviata';
$lang['general_word_received'] = 'Ricevuta';
$lang['general_word_requested'] = 'Richiesta';
$lang['general_word_queued'] = 'In coda';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Invalido (Ignora)';
$lang['general_word_qslcard'] = 'Cartolina QSL';
$lang['general_word_qslcard_management'] = 'Gestione QSL';
$lang['general_word_qslcards'] = 'Cartoline QSL';
$lang['general_word_qslcard_direct'] = 'Diretta';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Elettronica';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'Cartoline eQSL';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Modifica QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Segna QSL Ricevuta (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Segna QSL Ricevuta (Diretta)';
$lang['general_mark_qsl_rx_electronic'] = 'Segna QSL Ricevuta (Elettronico)';
$lang['general_mark_qsl_tx_bureau'] = 'Segna QSL Inviata (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Segna QSL Inviata (Direct)';
$lang['general_mark_qsl_requested'] = 'Segna QSL come richiesto';
$lang['general_mark_qsl_requested_bureau'] = 'Segna QSL come richiesto (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Segna QSL come richiesto (Diretta)';
$lang['general_mark_qsl_not_required'] = 'Segna QSL non come richiesto';

$lang['general_delete_qso'] = 'Cancella QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Distanza Totale';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Luogo Stazione';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Stazione';

$lang['gen_hamradio_call'] = 'Nominativo';
$lang['gen_hamradio_callsign'] = 'Nominativo';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Modo';
$lang['gen_hamradio_rst_sent'] = 'Inviato';
$lang['gen_hamradio_rst_rcvd'] = 'Ricevuto';
$lang['gen_hamradio_band'] = 'Banda';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Banda (RX)';
$lang['gen_hamradio_frequency'] = 'Frequenza';
$lang['gen_hamradio_frequency_rx'] = 'Frequenza (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (I)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Scambio (I)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Scambio (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Locatore';
$lang['gen_hamradio_transmit_power'] = 'Potenza di Trasmissione (W)';
$lang['gen_hamradio_propagation_mode'] = 'Modo di Propagazione';

$lang['gen_hamradio_satellite_name'] = 'Nome Satellite';
$lang['gen_hamradio_satellite_mode'] = 'Modo Satellite';

$lang['gen_hamradio_logbook'] = 'Logbook';
$lang['gen_hamradio_award'] = "Award";

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'Zona CQ';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'Stato USA';
$lang['gen_hamradio_county_reference'] = 'Contea USA';
$lang['gen_hamradio_iota_reference'] = 'Referenza IOTA';
$lang['gen_hamradio_sota_reference'] = 'Referenza SOTA';
$lang['gen_hamradio_wwff_reference'] = 'Referenza WWFF';
$lang['gen_hamradio_pota_reference'] = 'Referenza POTA';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'Stato';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Quadratone';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_gridsquare_show'] = "Show Locator";
$lang['gen_hamradio_latitude'] = "Latitude";
$lang['gen_hamradio_longitude'] = "Longitude";
$lang['gen_hamradio_bearing'] = "Bearing";
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operatore';

$lang['gen_hamradio_sig'] = 'Seg';
$lang['gen_hamradio_sig_info'] = 'Info Seg';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then";
$lang['gen_find_zone_part2'] = "click here";
$lang['gen_find_zone_part3'] = "to find it!";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Hai fatto';
$lang['dashboard_qsos_today'] = 'QSO oggi!';
$lang['dashboard_qso_breakdown'] = 'Riepilogo QSO';
$lang['dashboard_countries_breakdown'] = 'Riepilogo Paesi';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'Dalla data';

$lang['gen_this_qso_was_confirmed_on'] = 'Questo QSO è stato confermato il';

$lang['error_no_logbook_found'] = 'Non è stato trovato nessun logbook. È necessario definire un logbook in Logbooks di Stazione! Vai qui:';

$lang['copy_to_clipboard'] = 'Copia';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';

$lang['datatables_language'] = "it-IT";
